@@ -444,7 +444,7 @@ class _GitRefInfo:
             return _parse_git_timestamp_iso_strict(timestamp)
 
     def __repr__(self):
-        return ("_GitRefInfo(ref={!r}, commit={!r}, creatordate={!r}," " committerdate={!r}, taggerdate={!r})").format(
+        return ("_GitRefInfo(ref={!r}, commit={!r}, creatordate={!r}, committerdate={!r}, taggerdate={!r})").format(
             self.fullref, self.commit_offset, self.creatordate, self.committerdate, self.taggerdate
         )
 
@@ -654,19 +654,47 @@ class Version:
 
         import packaging.version as pv
 
-        return (
-            pv.Version(self.base) < pv.Version(other.base)
-            and _blank(self.stage, "") < _blank(other.stage, "")
-            and _blank(self.revision, 0) < _blank(other.revision, 0)
-            and _blank(self.distance, 0) < _blank(other.distance, 0)
-            and _blank(self.commit, "") < _blank(other.commit, "")
-            and bool(self.dirty) < bool(other.dirty)
-            and _blank(self.tagged_metadata, "") < _blank(other.tagged_metadata, "")
-            and _blank(self.epoch, 0) < _blank(other.epoch, 0)
-            and _blank(self.branch, "") < _blank(other.branch, "")
-            and _blank(self.timestamp, dt.datetime(0, 0, 0, 0, 0, 0))
-            < _blank(other.timestamp, dt.datetime(0, 0, 0, 0, 0, 0))
-        )
+        parsable = True
+        try:
+            us = pv.Version(self.serialize(metadata=False))
+            them = pv.Version(other.serialize(metadata=False))
+            if us < them:
+                return True
+            elif us > them:
+                return False
+        except Exception:
+            parsable = False
+
+        common_pairs = [
+            (_blank(self.distance, 0), _blank(other.distance, 0)),
+            (_blank(self.commit, ""), _blank(other.commit, "")),
+            (bool(self.dirty), bool(other.dirty)),
+            (_blank(self.tagged_metadata, ""), _blank(other.tagged_metadata, "")),
+            (_blank(self.branch, ""), _blank(other.branch, "")),
+            (
+                _blank(self.timestamp, dt.datetime(1, 1, 1, 0, 0, 0)),
+                _blank(other.timestamp, dt.datetime(1, 1, 1, 0, 0, 0)),
+            ),
+        ]
+
+        if parsable:
+            pairs = common_pairs
+        else:
+            pairs = [
+                (_blank(self.epoch, 0), _blank(other.epoch, 0)),
+                (pv.Version(self.base), pv.Version(other.base)),
+                (_blank(self.stage, ""), _blank(other.stage, "")),
+                (_blank(self.revision, 0), _blank(other.revision, 0)),
+                *common_pairs,
+            ]
+
+        for (a, b) in pairs:
+            if a < b:  # type: ignore
+                return True
+            elif a > b:  # type: ignore
+                return False
+
+        return False
 
     def serialize(
         self,
@@ -703,6 +731,9 @@ class Version:
             * {branch}
             * {branch_escaped} which omits any non-letter/number characters
             * {timestamp} which expands to YYYYmmddHHMMSS as UTC
+            * {major} (first part of `base` split on `.`, or 0)
+            * {minor} (second part of `base` split on `.`, or 0)
+            * {patch} (third part of `base` split on `.`, or 0)
         :param style: Built-in output formats. Will default to PEP 440 if not
             set and no custom format given. If you specify both a style and a
             custom format, then the format will be validated against the
@@ -731,6 +762,8 @@ class Version:
                 out = format(new_version)
             else:
                 try:
+                    base_parts = base.split(".")
+
                     out = format.format(
                         base=base,
                         stage=_blank(self.stage, ""),
@@ -743,6 +776,9 @@ class Version:
                         branch=_blank(self.branch, ""),
                         branch_escaped=_escape_branch(_blank(self.branch, "")),
                         timestamp=self.timestamp.strftime("%Y%m%d%H%M%S") if self.timestamp else "",
+                        major=base_parts[0] if len(base_parts) > 0 else "0",
+                        minor=base_parts[1] if len(base_parts) > 1 else "0",
+                        patch=base_parts[2] if len(base_parts) > 2 else "0",
                     )
                 except KeyError as e:
                     raise KeyError("Format contains invalid placeholder: {}".format(e))
